<?php
require_once '../../includes/config.php';
require_once '../../includes/auth.php';
header('Content-Type: application/json; charset=utf-8');

// التحقق من الصلاحيات
if (!$auth->hasPermission('manage_projects')) {
    http_response_code(403);
    echo json_encode(['error' => 'ليس لديك صلاحية للوصول']);
    exit;
}

$id = $_GET['id'] ?? null;
if (!$id) {
    http_response_code(400);
    echo json_encode(['error' => 'معرف المشروع مطلوب']);
    exit;
}

switch ($_SERVER['REQUEST_METHOD']) {
    case 'GET':
        // جلب تفاصيل المشروع
        try {
            $project = getRow("
                SELECT p.*, c.name as client_name 
                FROM projects p
                LEFT JOIN clients c ON p.client_id = c.id
                WHERE p.id = ?
            ", [$id]);

            if (!$project) {
                http_response_code(404);
                echo json_encode(['error' => 'المشروع غير موجود']);
                exit;
            }

            // إضافة المعلومات التفصيلية
            $project['documents'] = getAll("
                SELECT * FROM project_documents
                WHERE project_id = ?
            ", [$id]);

            $project['workers'] = getAll("
                SELECT w.* 
                FROM project_workers pw
                JOIN workers w ON pw.worker_id = w.id
                WHERE pw.project_id = ?
            ", [$id]);

            $project['expenses'] = getAll("
                SELECT * FROM expenses
                WHERE project_id = ?
                ORDER BY date DESC
                LIMIT 10
            ", [$id]);

            $project['updates'] = getAll("
                SELECT * FROM project_updates
                WHERE project_id = ?
                ORDER BY update_date DESC
            ", [$id]);

            echo json_encode([
                'status' => 'success',
                'data' => $project
            ]);
        } catch (Exception $e) {
            http_response_code(500);
            echo json_encode(['error' => 'خطأ في جلب البيانات']);
        }
        break;

    case 'PUT':
        // تحديث بيانات المشروع
        try {
            $data = json_decode(file_get_contents('php://input'), true);
            
            // التحقق من وجود المشروع
            $project = getRow("SELECT * FROM projects WHERE id = ?", [$id]);
            if (!$project) {
                http_response_code(404);
                echo json_encode(['error' => 'المشروع غير موجود']);
                exit;
            }

            $db->beginTransaction();

            // تحديث البيانات الأساسية
            $update_data = [
                'name' => $data['name'] ?? $project['name'],
                'client_id' => $data['client_id'] ?? $project['client_id'],
                'start_date' => $data['start_date'] ?? $project['start_date'],
                'end_date' => $data['end_date'] ?? $project['end_date'],
                'budget' => $data['budget'] ?? $project['budget'],
                'status' => $data['status'] ?? $project['status'],
                'updated_by' => $_SESSION['user_id'],
                'updated_at' => date('Y-m-d H:i:s')
            ];

            $db->update('projects', $update_data, 'id = ?', [$id]);

            // تحديث المستندات
            if (!empty($data['new_documents'])) {
                foreach ($data['new_documents'] as $doc) {
                    $doc_path = uploadFile($doc, 'project_documents');
                    $db->insert('project_documents', [
                        'project_id' => $id,
                        'type' => $doc['type'],
                        'file_path' => $doc_path,
                        'expiry_date' => $doc['expiry_date'] ?? null,
                        'created_at' => date('Y-m-d H:i:s')
                    ]);
                }
            }

            $db->commit();

            echo json_encode([
                'status' => 'success',
                'message' => 'تم تحديث بيانات المشروع بنجاح'
            ]);
        } catch (Exception $e) {
            $db->rollback();
            http_response_code(400);
            echo json_encode(['error' => $e->getMessage()]);
        }
        break;

    case 'DELETE':
        // حذف المشروع
        try {
            // التحقق من وجود المشروع
            $project = getRow("SELECT * FROM projects WHERE id = ?", [$id]);
            if (!$project) {
                http_response_code(404);
                echo json_encode(['error' => 'المشروع غير موجود']);
                exit;
            }

            $db->beginTransaction();

            // حذف المستندات
            $documents = getAll("SELECT file_path FROM project_documents WHERE project_id = ?", [$id]);
            foreach ($documents as $doc) {
                deleteFile($doc['file_path']);
            }
            $db->delete('project_documents', 'project_id = ?', [$id]);

            // حذف العلاقات
            $db->delete('project_workers', 'project_id = ?', [$id]);
            $db->delete('expenses', 'project_id = ?', [$id]);
            $db->delete('project_updates', 'project_id = ?', [$id]);
            
            // تحديث حالة المشروع بدلاً من الحذف الفعلي
            $db->update('projects', 
                ['status' => 'deleted', 'deleted_at' => date('Y-m-d H:i:s')],
                'id = ?', 
                [$id]
            );

            $db->commit();

            echo json_encode([
                'status' => 'success',
                'message' => 'تم حذف المشروع بنجاح'
            ]);
        } catch (Exception $e) {
            $db->rollback();
            http_response_code(400);
            echo json_encode(['error' => $e->getMessage()]);
        }
        break;

    default:
        http_response_code(405);
        echo json_encode(['error' => 'طريقة الطلب غير مدعومة']);
}