<?php
require_once '../../includes/config.php';
require_once '../../includes/auth.php';
header('Content-Type: application/json; charset=utf-8');

// التحقق من الصلاحيات
if (!$auth->hasPermission('manage_projects')) {
    http_response_code(403);
    echo json_encode(['error' => 'ليس لديك صلاحية للوصول']);
    exit;
}

switch ($_SERVER['REQUEST_METHOD']) {
    case 'GET':
        // جلب قائمة المشاريع
        try {
            $where = "1=1";
            $params = [];
            
            // فلترة حسب الحالة
            if (isset($_GET['status'])) {
                $where .= " AND p.status = ?";
                $params[] = $_GET['status'];
            }
            
            // فلترة حسب العميل
            if (isset($_GET['client_id'])) {
                $where .= " AND p.client_id = ?";
                $params[] = $_GET['client_id'];
            }
            
            // فلترة حسب التاريخ
            if (isset($_GET['start_date'])) {
                $where .= " AND p.start_date >= ?";
                $params[] = $_GET['start_date'];
            }
            if (isset($_GET['end_date'])) {
                $where .= " AND p.end_date <= ?";
                $params[] = $_GET['end_date'];
            }

            $query = "
                SELECT 
                    p.*,
                    c.name as client_name,
                    COUNT(DISTINCT pw.worker_id) as workers_count,
                    SUM(DISTINCT e.amount) as total_expenses
                FROM projects p
                LEFT JOIN clients c ON p.client_id = c.id
                LEFT JOIN project_workers pw ON p.id = pw.project_id
                LEFT JOIN expenses e ON p.id = e.project_id
                WHERE $where
                GROUP BY p.id
                ORDER BY p.created_at DESC
            ";

            $projects = getAll($query, $params);
            
            // تحميل معلومات إضافية لكل مشروع
            foreach ($projects as &$project) {
                // المستندات
                $project['documents'] = getAll("
                    SELECT * FROM project_documents 
                    WHERE project_id = ?
                ", [$project['id']]);
                
                // آخر تحديث
                $project['last_update'] = getRow("
                    SELECT * FROM project_updates 
                    WHERE project_id = ? 
                    ORDER BY update_date DESC 
                    LIMIT 1
                ", [$project['id']]);
                
                // إحصائيات العمال
                $project['worker_stats'] = getRow("
                    SELECT 
                        COUNT(*) as total_workers,
                        SUM(CASE WHEN status = 'active' THEN 1 ELSE 0 END) as active_workers
                    FROM project_workers 
                    WHERE project_id = ?
                ", [$project['id']]);
            }

            echo json_encode([
                'status' => 'success',
                'data' => $projects
            ]);
        } catch (Exception $e) {
            http_response_code(500);
            echo json_encode(['error' => 'خطأ في جلب البيانات']);
        }
        break;

    case 'POST':
        // إضافة مشروع جديد
        try {
            $data = json_decode(file_get_contents('php://input'), true);
            
            // التحقق من البيانات المطلوبة
            $required_fields = ['name', 'client_id', 'start_date', 'end_date', 'budget'];
            foreach ($required_fields as $field) {
                if (!isset($data[$field]) || empty($data[$field])) {
                    throw new Exception("حقل {$field} مطلوب");
                }
            }

            $db->beginTransaction();

            // إضافة المشروع
            $project_data = [
                'name' => $data['name'],
                'client_id' => $data['client_id'],
                'start_date' => $data['start_date'],
                'end_date' => $data['end_date'],
                'budget' => $data['budget'],
                'status' => 'pending',
                'created_by' => $_SESSION['user_id'],
                'created_at' => date('Y-m-d H:i:s')
            ];

            $db->insert('projects', $project_data);
            $project_id = $db->lastInsertId();

            // إضافة المستندات
            if (!empty($data['documents'])) {
                foreach ($data['documents'] as $doc) {
                    $doc_path = uploadFile($doc, 'project_documents');
                    $db->insert('project_documents', [
                        'project_id' => $project_id,
                        'type' => $doc['type'],
                        'file_path' => $doc_path,
                        'expiry_date' => $doc['expiry_date'] ?? null,
                        'created_at' => date('Y-m-d H:i:s')
                    ]);
                }
            }

            $db->commit();

            // إرسال إشعار
            addNotification(
                $_SESSION['user_id'],
                "تم إضافة مشروع جديد: {$data['name']}"
            );

            echo json_encode([
                'status' => 'success',
                'message' => 'تم إضافة المشروع بنجاح',
                'data' => ['id' => $project_id]
            ]);
        } catch (Exception $e) {
            $db->rollback();
            http_response_code(400);
            echo json_encode(['error' => $e->getMessage()]);
        }
        break;

    default:
        http_response_code(405);
        echo json_encode(['error' => 'طريقة الطلب غير مدعومة']);
}