<?php
require_once '../../includes/config.php';
require_once '../../includes/auth.php';
header('Content-Type: application/json; charset=utf-8');

if (!$auth->hasPermission('view_reports')) {
    http_response_code(403);
    echo json_encode(['error' => 'ليس لديك صلاحية للوصول']);
    exit;
}

try {
    $start_date = $_GET['start_date'] ?? date('Y-m-01');
    $end_date = $_GET['end_date'] ?? date('Y-m-t');

    // ملخص العمال
    $workers_summary = getRow("
        SELECT 
            COUNT(*) as total_workers,
            SUM(CASE WHEN status = 'active' THEN 1 ELSE 0 END) as active_workers,
            AVG(hourly_rate) as avg_hourly_rate
        FROM workers
    ");

    // تحليل الحضور والغياب
    $attendance_analysis = getAll("
        SELECT 
            w.id,
            w.name,
            COUNT(DISTINCT a.date) as attendance_days,
            SUM(a.hours_worked) as total_hours,
            AVG(a.hours_worked) as avg_hours_per_day,
            COUNT(CASE WHEN a.status = 'late' THEN 1 END) as late_count
        FROM workers w
        LEFT JOIN attendance a ON w.id = a.worker_id
        WHERE a.date BETWEEN ? AND ?
        GROUP BY w.id
        ORDER BY total_hours DESC
    ", [$start_date, $end_date]);

    // تحليل المهارات
    $skills_analysis = getAll("
        SELECT 
            s.name as skill_name,
            COUNT(DISTINCT ws.worker_id) as workers_count,
            AVG(w.hourly_rate) as avg_rate
        FROM skills s
        JOIN worker_skills ws ON s.id = ws.skill_id
        JOIN workers w ON ws.worker_id = w.id
        GROUP BY s.id
        ORDER BY workers_count DESC
    ");

    // تحليل التكاليف
    $cost_analysis = getAll("
        SELECT 
            w.id,
            w.name,
            w.hourly_rate,
            SUM(a.hours_worked) as total_hours,
            (w.hourly_rate * SUM(a.hours_worked)) as total_cost
        FROM workers w
        JOIN attendance a ON w.id = a.worker_id
        WHERE a.date BETWEEN ? AND ?
        GROUP BY w.id
        ORDER BY total_cost DESC
    ", [$start_date, $end_date]);

    // تحليل الأداء
    $performance_analysis = getAll("
        SELECT 
            w.id,
            w.name,
            COUNT(DISTINCT p.id) as projects_count,
            AVG(we.rating) as avg_rating,
            COUNT(DISTINCT we.id) as evaluations_count
        FROM workers w
        LEFT JOIN project_workers pw ON w.id = pw.worker_id
        LEFT JOIN projects p ON pw.project_id = p.id
        LEFT JOIN worker_evaluations we ON w.id = we.worker_id
        WHERE we.evaluation_date BETWEEN ? AND ?
        GROUP BY w.id
        ORDER BY avg_rating DESC
    ", [$start_date, $end_date]);

    // مؤشرات الأداء الرئيسية
    $kpis = [
        'attendance_rate' => calculateAttendanceRate($start_date, $end_date),
        'avg_worker_cost' => calculateAverageWorkerCost($start_date, $end_date),
        'productivity_rate' => calculateProductivityRate($start_date, $end_date)
    ];

    echo json_encode([
        'status' => 'success',
        'data' => [
            'summary' => $workers_summary,
            'attendance' => $attendance_analysis,
            'skills' => $skills_analysis,
            'costs' => $cost_analysis,
            'performance' => $performance_analysis,
            'kpis' => $kpis
        ]
    ]);
} catch (Exception $e) {
    http_response_code(500);
    echo json_encode(['error' => 'خطأ في إنشاء التقرير']);
}

// دوال مساعدة لحساب مؤشرات الأداء
function calculateAttendanceRate($start_date, $end_date) {
    global $db;
    $data = getRow("
        SELECT 
            COUNT(DISTINCT CASE WHEN status = 'present' THEN date END) as present_days,
            COUNT(DISTINCT date) as total_days
        FROM attendance
        WHERE date BETWEEN ? AND ?
    ", [$start_date, $end_date]);
    
    return ($data['present_days'] / $data['total_days']) * 100;
}

function calculateAverageWorkerCost($start_date, $end_date) {
    global $db;
    return getValue("
        SELECT AVG(w.hourly_rate * a.hours_worked)
        FROM workers w
        JOIN attendance a ON w.id = a.worker_id
        WHERE a.date BETWEEN ? AND ?
    ", [$start_date, $end_date]);
}

function calculateProductivityRate($start_date, $end_date) {
    global $db;
    $data = getRow("
        SELECT 
            COUNT(DISTINCT CASE WHEN p.status = 'completed' THEN p.id END) as completed_projects,
            COUNT(DISTINCT p.id) as total_projects
        FROM projects p
        WHERE p.end_date BETWEEN ? AND ?
    ", [$start_date, $end_date]);
    
    return ($data['completed_projects'] / $data['total_projects']) * 100;
}