<?php
require_once '../../includes/config.php';
require_once '../../includes/auth.php';
header('Content-Type: application/json; charset=utf-8');

// التحقق من الصلاحيات
if (!$auth->hasPermission('manage_workers')) {
    http_response_code(403);
    echo json_encode(['error' => 'ليس لديك صلاحية للوصول']);
    exit;
}

switch ($_SERVER['REQUEST_METHOD']) {
    case 'GET':
        // جلب قائمة العمال
        try {
            $where = "1=1";
            $params = [];
            
            // فلترة حسب الحالة
            if (isset($_GET['status'])) {
                $where .= " AND w.status = ?";
                $params[] = $_GET['status'];
            }
            
            // فلترة حسب المشروع
            if (isset($_GET['project_id'])) {
                $where .= " AND EXISTS (
                    SELECT 1 FROM project_workers pw 
                    WHERE pw.worker_id = w.id 
                    AND pw.project_id = ?
                )";
                $params[] = $_GET['project_id'];
            }
            
            // فلترة حسب المهارات
            if (isset($_GET['skill'])) {
                $where .= " AND EXISTS (
                    SELECT 1 FROM worker_skills ws 
                    JOIN skills s ON ws.skill_id = s.id 
                    WHERE ws.worker_id = w.id 
                    AND s.name = ?
                )";
                $params[] = $_GET['skill'];
            }

            $query = "
                SELECT 
                    w.*,
                    GROUP_CONCAT(DISTINCT s.name) as skills,
                    GROUP_CONCAT(DISTINCT p.name) as projects,
                    COUNT(DISTINCT a.id) as attendance_count,
                    AVG(a.hours_worked) as avg_hours_worked
                FROM workers w
                LEFT JOIN worker_skills ws ON w.id = ws.worker_id
                LEFT JOIN skills s ON ws.skill_id = s.id
                LEFT JOIN project_workers pw ON w.id = pw.worker_id
                LEFT JOIN projects p ON pw.project_id = p.id
                LEFT JOIN attendance a ON w.id = a.worker_id
                WHERE $where
                GROUP BY w.id
                ORDER BY w.created_at DESC
            ";

            $workers = getAll($query, $params);
            
            // تحميل معلومات إضافية لكل عامل
            foreach ($workers as &$worker) {
                // المستندات
                $worker['documents'] = getAll("
                    SELECT * FROM worker_documents 
                    WHERE worker_id = ?
                ", [$worker['id']]);
                
                // آخر تقييم
                $worker['last_evaluation'] = getRow("
                    SELECT * FROM worker_evaluations 
                    WHERE worker_id = ? 
                    ORDER BY evaluation_date DESC 
                    LIMIT 1
                ", [$worker['id']]);
                
                // إحصائيات الحضور
                $worker['attendance_stats'] = getRow("
                    SELECT 
                        COUNT(*) as total_days,
                        SUM(hours_worked) as total_hours,
                        AVG(hours_worked) as avg_hours,
                        COUNT(CASE WHEN status = 'late' THEN 1 END) as late_count
                    FROM attendance 
                    WHERE worker_id = ?
                ", [$worker['id']]);
            }

            echo json_encode([
                'status' => 'success',
                'data' => $workers
            ]);
        } catch (Exception $e) {
            http_response_code(500);
            echo json_encode(['error' => 'خطأ في جلب البيانات']);
        }
        break;

    case 'POST':
        // إضافة عامل جديد
        try {
            $data = json_decode(file_get_contents('php://input'), true);
            
            // التحقق من البيانات المطلوبة
            $required_fields = ['name', 'national_id', 'phone', 'job_title', 'hourly_rate'];
            foreach ($required_fields as $field) {
                if (!isset($data[$field]) || empty($data[$field])) {
                    throw new Exception("حقل {$field} مطلوب");
                }
            }

            // التحقق من عدم تكرار رقم الهوية
            $exists = getValue("
                SELECT COUNT(*) FROM workers 
                WHERE national_id = ?
            ", [$data['national_id']]);
            
            if ($exists) {
                throw new Exception("رقم الهوية مسجل مسبقاً");
            }

            $db->beginTransaction();

            // إضافة العامل
            $worker_data = [
                'name' => $data['name'],
                'national_id' => $data['national_id'],
                'phone' => $data['phone'],
                'email' => $data['email'] ?? null,
                'address' => $data['address'] ?? null,
                'job_title' => $data['job_title'],
                'hourly_rate' => $data['hourly_rate'],
                'status' => 'active',
                'created_by' => $_SESSION['user_id'],
                'created_at' => date('Y-m-d H:i:s')
            ];

            $db->insert('workers', $worker_data);
            $worker_id = $db->lastInsertId();

            // إضافة المهارات
            if (!empty($data['skills'])) {
                foreach ($data['skills'] as $skill_id) {
                    $db->insert('worker_skills', [
                        'worker_id' => $worker_id,
                        'skill_id' => $skill_id
                    ]);
                }
            }

            // إضافة المستندات
            if (!empty($data['documents'])) {
                foreach ($data['documents'] as $doc) {
                    $doc_path = uploadFile($doc, 'worker_documents');
                    $db->insert('worker_documents', [
                        'worker_id' => $worker_id,
                        'type' => $doc['type'],
                        'file_path' => $doc_path,
                        'expiry_date' => $doc['expiry_date'] ?? null,
                        'created_at' => date('Y-m-d H:i:s')
                    ]);
                }
            }

            $db->commit();

            // إرسال إشعار
            addNotification(
                $_SESSION['user_id'],
                "تم إضافة عامل جديد: {$data['name']}"
            );

            echo json_encode([
                'status' => 'success',
                'message' => 'تم إضافة العامل بنجاح',
                'data' => ['id' => $worker_id]
            ]);
        } catch (Exception $e) {
            $db->rollback();
            http_response_code(400);
            echo json_encode(['error' => $e->getMessage()]);
        }
        break;

    default:
        http_response_code(405);
        echo json_encode(['error' => 'طريقة الطلب غير مدعومة']);
}