// Chart.js Configuration
import Chart from 'chart.js';

// Arabic Font Configuration
Chart.defaults.global.defaultFontFamily = 'Cairo';
Chart.defaults.global.defaultFontSize = 14;

// Custom Colors
const chartColors = {
  primary: '#2c3e50',
  secondary: '#3498db',
  success: '#27ae60',
  danger: '#e74c3c',
  warning: '#f39c12',
  info: '#3498db',
  light: '#ecf0f1',
  dark: '#2c3e50'
};

// Chart Configurations Object
const ChartConfigs = {
  // Project Progress Chart
  projectProgress: {
    type: 'doughnut',
    options: {
      responsive: true,
      maintainAspectRatio: false,
      legend: {
        position: 'bottom',
        rtl: true
      },
      tooltips: {
        rtl: true,
        callbacks: {
          label: function(tooltipItem, data) {
            return data.labels[tooltipItem.index] + ': ' +
              data.datasets[0].data[tooltipItem.index] + '%';
          }
        }
      }
    }
  },

  // Financial Chart
  financial: {
    type: 'bar',
    options: {
      responsive: true,
      maintainAspectRatio: false,
      scales: {
        xAxes: [{
          gridLines: {
            display: false
          }
                }],
        yAxes: [{
          ticks: {
            beginAtZero: true,
            callback: function(value) {
              return value.toLocaleString('ar-SA') + ' ريال';
            }
          }
                }]
      },
      tooltips: {
        rtl: true,
        callbacks: {
          label: function(tooltipItem, data) {
            return tooltipItem.value.toLocaleString('ar-SA') + ' ريال';
          }
        }
      }
    }
  }
};

// Chart Creation Functions
class ChartManager {
  static initProjectProgressChart(elementId, data) {
    const ctx = document.getElementById(elementId).getContext('2d');
    return new Chart(ctx, {
      type: ChartConfigs.projectProgress.type,
      data: {
        labels: data.labels,
        datasets: [{
          data: data.values,
          backgroundColor: Object.values(chartColors)
                }]
      },
      options: ChartConfigs.projectProgress.options
    });
  }

  static initFinancialChart(elementId, data) {
    const ctx = document.getElementById(elementId).getContext('2d');
    return new Chart(ctx, {
      type: ChartConfigs.financial.type,
      data: {
        labels: data.months,
        datasets: [
          {
            label: 'الإيرادات',
            data: data.revenues,
            backgroundColor: chartColors.success,
            borderColor: chartColors.success,
            borderWidth: 1
                    },
          {
            label: 'المصروفات',
            data: data.expenses,
            backgroundColor: chartColors.danger,
            borderColor: chartColors.danger,
            borderWidth: 1
                    }
                ]
      },
      options: ChartConfigs.financial.options
    });
  }

  static initWorkerProductivityChart(elementId, data) {
    const ctx = document.getElementById(elementId).getContext('2d');
    return new Chart(ctx, {
      type: 'line',
      data: {
        labels: data.dates,
        datasets: [{
          label: 'ساعات العمل',
          data: data.hours,
          borderColor: chartColors.primary,
          fill: false
                }]
      },
      options: {
        responsive: true,
        scales: {
          yAxes: [{
            ticks: {
              beginAtZero: true
            }
                    }]
        }
      }
    });
  }
}

// Data Update Functions
class ChartUpdater {
  static async updateProjectProgress(chart, projectId) {
    try {
      const response = await fetch(`/api/projects/${projectId}/progress`);
      const data = await response.json();

      chart.data.labels = data.labels;
      chart.data.datasets[0].data = data.values;
      chart.update();
    } catch (error) {
      console.error('Error updating project progress chart:', error);
    }
  }

  static async updateFinancialData(chart, year, month) {
    try {
      const response = await fetch(`/api/financial/summary?year=${year}&month=${month}`);
      const data = await response.json();

      chart.data.datasets[0].data = data.revenues;
      chart.data.datasets[1].data = data.expenses;
      chart.update();
    } catch (error) {
      console.error('Error updating financial chart:', error);
    }
  }
}

// Export Module
export {
  ChartManager,
  ChartUpdater,
  chartColors
};