// Global Variables & Configurations
const CONFIG = {
  API_URL: '/api',
  DATETIME_FORMAT: 'YYYY-MM-DD HH:mm:ss',
  CURRENCY: 'SAR',
  DECIMAL_PLACES: 2
};

// Document Ready Handler
document.addEventListener('DOMContentLoaded', function() {
  initializeComponents();
  setupEventListeners();
  initializeNotifications();
});

// Initialize All Components
function initializeComponents() {
  initializeDatePickers();
  initializeSelect2();
  initializeTooltips();
  initializeDataTables();
}

// Date Picker Initialization
function initializeDatePickers() {
  const dateInputs = document.querySelectorAll('.date-picker');
  dateInputs.forEach(input => {
    new Datepicker(input, {
      format: 'yyyy-mm-dd',
      language: 'ar',
      autoclose: true,
      rtl: true
    });
  });
}

// Select2 Initialization
function initializeSelect2() {
  const selects = document.querySelectorAll('.select2');
  selects.forEach(select => {
    new Select2(select, {
      dir: 'rtl',
      language: 'ar'
    });
  });
}

// Data Tables Configuration
function initializeDataTables() {
  const tables = document.querySelectorAll('.data-table');
  tables.forEach(table => {
    new DataTable(table, {
      language: {
        url: '/assets/js/plugins/datatable-ar.json'
      },
      responsive: true,
      ordering: true,
      pageLength: 25
    });
  });
}

// Form Validation
class FormValidator {
  static validate(form) {
    let isValid = true;
    const requiredFields = form.querySelectorAll('[required]');

    requiredFields.forEach(field => {
      if (!field.value.trim()) {
        this.showError(field, 'هذا الحقل مطلوب');
        isValid = false;
      } else {
        this.clearError(field);
      }
    });

    return isValid;
  }

  static showError(field, message) {
    const errorDiv = document.createElement('div');
    errorDiv.className = 'error-message';
    errorDiv.textContent = message;
    field.classList.add('error');
    field.parentNode.appendChild(errorDiv);
  }

  static clearError(field) {
    field.classList.remove('error');
    const errorDiv = field.parentNode.querySelector('.error-message');
    if (errorDiv) {
      errorDiv.remove();
    }
  }
}

// API Handlers
const API = {
  async get(endpoint) {
    try {
      const response = await fetch(`${CONFIG.API_URL}${endpoint}`);
      return await response.json();
    } catch (error) {
      console.error('API Error:', error);
      throw error;
    }
  },

  async post(endpoint, data) {
    try {
      const response = await fetch(`${CONFIG.API_URL}${endpoint}`, {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json'
        },
        body: JSON.stringify(data)
      });
      return await response.json();
    } catch (error) {
      console.error('API Error:', error);
      throw error;
    }
  }
};

// Utility Functions
const Utils = {
  formatCurrency(amount) {
    return new Intl.NumberFormat('ar-SA', {
      style: 'currency',
      currency: CONFIG.CURRENCY
    }).format(amount);
  },

  formatDate(date) {
    return new Date(date).toLocaleDateString('ar-SA');
  },

  formatDateTime(datetime) {
    return new Date(datetime).toLocaleString('ar-SA');
  },

  generateUniqueId() {
    return Date.now().toString(36) + Math.random().toString(36).substr(2);
  }
};

// Notification System
class NotificationSystem {
  static show(message, type = 'info') {
    const notification = document.createElement('div');
    notification.className = `notification notification-${type}`;
    notification.textContent = message;

    document.body.appendChild(notification);

    setTimeout(() => {
      notification.remove();
    }, 3000);
  }
}

// Event Listeners
function setupEventListeners() {
  // Form Submissions
  document.querySelectorAll('form').forEach(form => {
    form.addEventListener('submit', function(e) {
      if (!FormValidator.validate(this)) {
        e.preventDefault();
      }
    });
  });

  // Dynamic Content Loading
  document.querySelectorAll('[data-load]').forEach(element => {
    element.addEventListener('click', async function(e) {
      e.preventDefault();
      const url = this.getAttribute('data-load');
      const target = this.getAttribute('data-target');

      try {
        const response = await API.get(url);
        document.querySelector(target).innerHTML = response.html;
      } catch (error) {
        NotificationSystem.show('حدث خطأ أثناء تحميل المحتوى', 'error');
      }
    });
  });
}

// Export Module
export {
  API,
  Utils,
  FormValidator,
  NotificationSystem
};