/**
 * نظام الإشعارات المتكامل
 */

class NotificationSystem {
  constructor() {
    this.container = this.createContainer();
    this.notifications = [];
    this.init();
  }

  // تهيئة نظام الإشعارات
  init() {
    document.body.appendChild(this.container);
    this.initializeWebSocket();
    this.setupEventListeners();
  }

  // إنشاء حاوية الإشعارات
  createContainer() {
    const container = document.createElement('div');
    container.className = 'notifications-container';
    return container;
  }

  // إعداد WebSocket للإشعارات المباشرة
  initializeWebSocket() {
    this.ws = new WebSocket(`ws://${window.location.host}/notifications`);

    this.ws.onmessage = (event) => {
      const data = JSON.parse(event.data);
      this.show(data.message, data.type, data.duration);
    };

    this.ws.onclose = () => {
      // محاولة إعادة الاتصال بعد 5 ثواني
      setTimeout(() => this.initializeWebSocket(), 5000);
    };
  }

  // إظهار إشعار جديد
  show(message, type = 'info', duration = 5000) {
    const notification = this.createNotification(message, type);
    this.notifications.push(notification);
    this.container.appendChild(notification);

    // تحريك الإشعار للظهور
    setTimeout(() => {
      notification.classList.add('show');
    }, 100);

    // إزالة الإشعار بعد المدة المحددة
    if (duration > 0) {
      setTimeout(() => {
        this.remove(notification);
      }, duration);
    }

    return notification;
  }

  // إنشاء عنصر الإشعار
  createNotification(message, type) {
    const notification = document.createElement('div');
    notification.className = `notification notification-${type}`;

    // إضافة أيقونة حسب نوع الإشعار
    const icon = this.getIconForType(type);

    notification.innerHTML = `
            <div class="notification-icon">${icon}</div>
            <div class="notification-content">
                <div class="notification-message">${message}</div>
            </div>
            <button class="notification-close">&times;</button>
        `;

    return notification;
  }

  // الحصول على أيقونة حسب نوع الإشعار
  getIconForType(type) {
    const icons = {
      success: '<i class="fas fa-check-circle"></i>',
      error: '<i class="fas fa-times-circle"></i>',
      warning: '<i class="fas fa-exclamation-triangle"></i>',
      info: '<i class="fas fa-info-circle"></i>'
    };
    return icons[type] || icons.info;
  }

  // إزالة إشعار
  remove(notification) {
    notification.classList.remove('show');
    setTimeout(() => {
      if (notification.parentElement === this.container) {
        this.container.removeChild(notification);
      }
      this.notifications = this.notifications.filter(n => n !== notification);
    }, 300);
  }

  // إزالة جميع الإشعارات
  clearAll() {
    this.notifications.forEach(notification => {
      this.remove(notification);
    });
  }

  // إعداد مستمعي الأحداث
  setupEventListeners() {
    this.container.addEventListener('click', (e) => {
      if (e.target.classList.contains('notification-close')) {
        const notification = e.target.closest('.notification');
        if (notification) {
          this.remove(notification);
        }
      }
    });
  }

  // إظهار إشعار نجاح
  success(message, duration = 5000) {
    return this.show(message, 'success', duration);
  }

  // إظهار إشعار خطأ
  error(message, duration = 5000) {
    return this.show(message, 'error', duration);
  }

  // إظهار إشعار تحذير
  warning(message, duration = 5000) {
    return this.show(message, 'warning', duration);
  }

  // إظهار إشعار معلومات
  info(message, duration = 5000) {
    return this.show(message, 'info', duration);
  }
}

// تصدير النظام
const notifications = new NotificationSystem();
export default notifications;