/**
 * نظام التحقق من المدخلات
 */

class FormValidator {
  constructor(form, options = {}) {
    this.form = form;
    this.options = {
      errorClass: 'input-error',
      errorMessageClass: 'error-message',
      validateOnInput: true,
      ...options
    };

    this.rules = {
      required: value => !!value.trim() || 'هذا الحقل مطلوب',
      email: value => /^[^\s@]+@[^\s@]+\.[^\s@]+$/.test(value) || 'البريد الإلكتروني غير صالح',
      phone: value => /^(05)[0-9]{8}$/.test(value) || 'رقم الجوال غير صالح',
      number: value => !isNaN(value) || 'يجب إدخال رقم صحيح',
      min: (value, min) => value.length >= min || `يجب أن لا يقل عن ${min} حروف`,
      max: (value, max) => value.length <= max || `يجب أن لا يزيد عن ${max} حروف`,
      nationalId: value => /^[1-2][0-9]{9}$/.test(value) || 'رقم الهوية غير صالح',
      password: value => /^(?=.*[A-Za-z])(?=.*\d)[A-Za-z\d]{8,}$/.test(value) ||
        'كلمة المرور يجب أن تحتوي على 8 أحرف على الأقل وتتضمن حروف وأرقام',
      match: (value, field) => value === this.form[field].value || 'القيم غير متطابقة'
    };

    this.init();
  }

  // تهيئة المحقق
  init() {
    if (this.options.validateOnInput) {
      this.setupLiveValidation();
    }

    this.form.addEventListener('submit', (e) => {
      if (!this.validateForm()) {
        e.preventDefault();
      }
    });
  }

  // إعداد التحقق المباشر
  setupLiveValidation() {
    const inputs = this.form.querySelectorAll('input, select, textarea');
    inputs.forEach(input => {
      input.addEventListener('input', () => {
        this.validateField(input);
      });

      input.addEventListener('blur', () => {
        this.validateField(input);
      });
    });
  }

  // التحقق من حقل معين
  validateField(field) {
    const rules = field.dataset.validate ? field.dataset.validate.split('|') : [];
    let isValid = true;
    let errorMessage = '';

    rules.forEach(rule => {
      const [ruleName, ruleValue] = rule.split(':');

      if (this.rules[ruleName]) {
        const result = this.rules[ruleName](field.value, ruleValue);

        if (typeof result === 'string') {
          isValid = false;
          errorMessage = result;
        }
      }
    });

    this.toggleError(field, !isValid, errorMessage);
    return isValid;
  }

  // التحقق من النموذج كاملاً
  validateForm() {
    const inputs = this.form.querySelectorAll('input, select, textarea');
    let isValid = true;

    inputs.forEach(input => {
      if (!this.validateField(input)) {
        isValid = false;
      }
    });

    return isValid;
  }

  // إظهار/إخفاء رسالة الخطأ
  toggleError(field, hasError, message = '') {
    const container = field.parentElement;
    let errorElement = container.querySelector(`.${this.options.errorMessageClass}`);

    if (hasError) {
      field.classList.add(this.options.errorClass);

      if (!errorElement) {
        errorElement = document.createElement('div');
        errorElement.className = this.options.errorMessageClass;
        container.appendChild(errorElement);
      }

      errorElement.textContent = message;
    } else {
      field.classList.remove(this.options.errorClass);
      if (errorElement) {
        errorElement.remove();
      }
    }
  }

  // إضافة قاعدة تحقق جديدة
  addRule(name, validator) {
    this.rules[name] = validator;
  }

  // إعادة تعيين النموذج
  reset() {
    const errors = this.form.querySelectorAll(`.${this.options.errorMessageClass}`);
    const inputs = this.form.querySelectorAll(`.${this.options.errorClass}`);

    errors.forEach(error => error.remove());
    inputs.forEach(input => input.classList.remove(this.options.errorClass));
  }
}

// مثال على الاستخدام
/*
const form = document.querySelector('#myForm');
const validator = new FormValidator(form, {
    validateOnInput: true
});

// إضافة قاعدة تحقق مخصصة
validator.addRule('customRule', (value) => {
    return value.startsWith('ABC') || 'يجب أن يبدأ النص بـ ABC';
});
*/

export default FormValidator;