<?php
// منع الوصول المباشر للملف
if (!defined('SECURE_ACCESS')) {
    die('Access Denied');
}

/**
 * نظام إدارة المصادقة والصلاحيات
 */

class Auth {
    private static $instance = null;
    private $user = null;
    private $permissions = [];
    
    // نمط Singleton
    public static function getInstance() {
        if (self::$instance === null) {
            self::$instance = new self();
        }
        return self::$instance;
    }
    
    private function __construct() {
        $this->initSession();
        $this->loadUserData();
    }

    // تهيئة الجلسة
    private function initSession() {
        if (session_status() === PHP_SESSION_NONE) {
            session_start();
        }
    }

    // تحميل بيانات المستخدم
    private function loadUserData() {
        if (isset($_SESSION['user_id'])) {
            global $pdo;
            $stmt = $pdo->prepare("
                SELECT 
                    u.*,
                    r.name as role_name,
                    r.level as role_level
                FROM users u
                LEFT JOIN roles r ON u.role_id = r.id
                WHERE u.id = ? AND u.is_active = 1
            ");
            $stmt->execute([$_SESSION['user_id']]);
            $this->user = $stmt->fetch();

            if ($this->user) {
                $this->loadPermissions();
            }
        }
    }

    // تحميل صلاحيات المستخدم
    private function loadPermissions() {
        global $pdo;
        $stmt = $pdo->prepare("
            SELECT DISTINCT p.permission_key
            FROM user_permissions up
            JOIN permissions p ON up.permission_id = p.id
            WHERE up.user_id = ?
            UNION
            SELECT DISTINCT p.permission_key
            FROM role_permissions rp
            JOIN permissions p ON rp.permission_id = p.id
            WHERE rp.role_id = ?
        ");
        $stmt->execute([$this->user['id'], $this->user['role_id']]);
        $this->permissions = $stmt->fetchAll(PDO::FETCH_COLUMN);
    }

    // التحقق من تسجيل دخول المستخدم
    public function isLoggedIn() {
        return $this->user !== null;
    }

    // تسجيل دخول المستخدم
    public function login($username, $password) {
        global $pdo;
        
        try {
            $stmt = $pdo->prepare("
                SELECT * FROM users 
                WHERE username = ? AND is_active = 1
            ");
            $stmt->execute([$username]);
            $user = $stmt->fetch();

            if ($user && password_verify($password, $user['password'])) {
                // تحديث آخر تسجيل دخول
                $updateStmt = $pdo->prepare("
                    UPDATE users 
                    SET last_login = NOW(),
                        login_attempts = 0
                    WHERE id = ?
                ");
                $updateStmt->execute([$user['id']]);

                // تخزين بيانات الجلسة
                $_SESSION['user_id'] = $user['id'];
                $_SESSION['user_role'] = $user['role_id'];
                $_SESSION['last_activity'] = time();
                $_SESSION['csrf_token'] = bin2hex(random_bytes(32));

                // تسجيل نشاط الدخول
                logActivity($user['id'], 'login', 'تسجيل دخول ناجح');

                return true;
            } else {
                // زيادة عدد محاولات الدخول الفاشلة
                if ($user) {
                    $updateStmt = $pdo->prepare("
                        UPDATE users 
                        SET login_attempts = login_attempts + 1
                        WHERE id = ?
                    ");
                    $updateStmt->execute([$user['id']]);

                    // قفل الحساب بعد 5 محاولات فاشلة
                    if ($user['login_attempts'] >= 4) {
                        $updateStmt = $pdo->prepare("
                            UPDATE users 
                            SET is_active = 0,
                                locked_until = DATE_ADD(NOW(), INTERVAL 30 MINUTE)
                            WHERE id = ?
                        ");
                        $updateStmt->execute([$user['id']]);
                    }
                }

                return false;
            }
        } catch (PDOException $e) {
            logError('login_error', $e->getMessage());
            return false;
        }
    }

    // تسجيل خروج المستخدم
    public function logout() {
        if ($this->isLoggedIn()) {
            logActivity($this->user['id'], 'logout', 'تسجيل خروج');
        }
        
        session_destroy();
        $this->user = null;
        $this->permissions = [];
        
        // حذف كوكيز "تذكرني"
        if (isset($_COOKIE['remember_token'])) {
            setcookie('remember_token', '', time() - 3600, '/');
        }
    }

    // التحقق من صلاحية معينة
    public function hasPermission($permission) {
        return in_array($permission, $this->permissions);
    }

    // التحقق من مجموعة صلاحيات
    public function hasAnyPermission($permissions) {
        return !empty(array_intersect($permissions, $this->permissions));
    }

    // التحقق من جميع الصلاحيات
    public function hasAllPermissions($permissions) {
        return count(array_intersect($permissions, $this->permissions)) === count($permissions);
    }

    // التحقق من صلاحية المشروع
    public function canAccessProject($project_id) {
        if ($this->isAdmin()) return true;
        
        global $pdo;
        $stmt = $pdo->prepare("
            SELECT COUNT(*) FROM project_users 
            WHERE user_id = ? AND project_id = ?
        ");
        $stmt->execute([$this->user['id'], $project_id]);
        return $stmt->fetchColumn() > 0;
    }

    // التحقق من صلاحية العامل
    public function canManageWorker($worker_id) {
        if ($this->isAdmin()) return true;
        
        global $pdo;
        $stmt = $pdo->prepare("
            SELECT COUNT(*) FROM worker_supervisors 
            WHERE supervisor_id = ? AND worker_id = ?
        ");
        $stmt->execute([$this->user['id'], $worker_id]);
        return $stmt->fetchColumn() > 0;
    }

    // التحقق من صلاحية المدير
    public function isAdmin() {
        return $this->user['role_level'] >= 100;
    }

    // الحصول على بيانات المستخدم الحالي
    public function getCurrentUser() {
        return $this->user;
    }

    // التحقق من صحة الجلسة
    public function checkSession() {
        if (!$this->isLoggedIn()) {
            redirect('login.php');
        }

        // التحقق من timeout الجلسة
        if (isset($_SESSION['last_activity']) && 
            (time() - $_SESSION['last_activity'] > 1800)) {
            $this->logout();
            redirect('login.php?timeout=1');
        }

        $_SESSION['last_activity'] = time();
    }

    // تغيير كلمة المرور
    public function changePassword($current_password, $new_password) {
        if (!$this->isLoggedIn()) {
            return false;
        }

        global $pdo;
        
        // التحقق من كلمة المرور الحالية
        if (!password_verify($current_password, $this->user['password'])) {
            return false;
        }

        // تحديث كلمة المرور
        $hashed_password = password_hash($new_password, PASSWORD_DEFAULT);
        $stmt = $pdo->prepare("
            UPDATE users 
            SET password = ?,
                password_changed_at = NOW()
            WHERE id = ?
        ");
        
        if ($stmt->execute([$hashed_password, $this->user['id']])) {
            logActivity($this->user['id'], 'password_change', 'تم تغيير كلمة المرور');
            return true;
        }
        
        return false;
    }

    // إعادة تعيين كلمة المرور
    public function resetPassword($email) {
        global $pdo;
        
        $stmt = $pdo->prepare("SELECT id FROM users WHERE email = ? AND is_active = 1");
        $stmt->execute([$email]);
        $user = $stmt->fetch();

        if ($user) {
            $token = bin2hex(random_bytes(32));
            $expires = date('Y-m-d H:i:s', strtotime('+1 hour'));

            $stmt = $pdo->prepare("
                INSERT INTO password_resets (user_id, token, expires_at)
                VALUES (?, ?, ?)
            ");
            
            if ($stmt->execute([$user['id'], $token, $expires])) {
                // إرسال بريد إعادة تعيين كلمة المرور
                sendPasswordResetEmail($email, $token);
                return true;
            }
        }
        
        return false;
    }
}

// دوال مساعدة للتحقق من الصلاحيات

function checkAdminAuth() {
    $auth = Auth::getInstance();
    if (!$auth->isLoggedIn() || !$auth->isAdmin()) {
        redirect('login.php');
    }
    $auth->checkSession();
}

function checkWorkerAuth() {
    $auth = Auth::getInstance();
    if (!$auth->isLoggedIn() || $auth->isAdmin()) {
        redirect('login.php');
    }
    $auth->checkSession();
}

function requirePermission($permission) {
    $auth = Auth::getInstance();
    if (!$auth->hasPermission($permission)) {
        redirect('error.php?type=permission');
    }
}

function isAdminLoggedIn() {
    $auth = Auth::getInstance();
    return $auth->isLoggedIn() && $auth->isAdmin();
}

function isWorkerLoggedIn() {
    $auth = Auth::getInstance();
    return $auth->isLoggedIn() && !$auth->isAdmin();
}

// تصدير كائن Auth
$auth = Auth::getInstance();