<?php
// منع الوصول المباشر للملف
if (!defined('SECURE_ACCESS')) {
    die('Access Denied');
}

/**
 * نظام إدارة قاعدة البيانات
 */

class Database {
    private static $instance = null;
    private $pdo;
    private $stmt;
    private $error;
    private $transaction_count = 0;

    // إعدادات قاعدة البيانات
    private $settings = [
        PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION,
        PDO::ATTR_DEFAULT_FETCH_MODE => PDO::FETCH_ASSOC,
        PDO::ATTR_EMULATE_PREPARES => false,
        PDO::MYSQL_ATTR_INIT_COMMAND => "SET NAMES utf8mb4 COLLATE utf8mb4_unicode_ci"
    ];

    // Constructor خاص لنمط Singleton
    private function __construct() {
        try {
            $dsn = "mysql:host=" . DB_HOST . ";dbname=" . DB_NAME . ";charset=utf8mb4";
            $this->pdo = new PDO($dsn, DB_USER, DB_PASS, $this->settings);
        } catch (PDOException $e) {
            $this->error = $e->getMessage();
            $this->logError();
            die("فشل الاتصال بقاعدة البيانات");
        }
    }

    // الحصول على نسخة وحيدة من الكلاس
    public static function getInstance() {
        if (self::$instance === null) {
            self::$instance = new self();
        }
        return self::$instance;
    }

    // تحضير الاستعلام
    public function prepare($sql) {
        $this->stmt = $this->pdo->prepare($sql);
        return $this;
    }

    // تنفيذ الاستعلام
    public function execute($params = []) {
        try {
            return $this->stmt->execute($params);
        } catch (PDOException $e) {
            $this->error = $e->getMessage();
            $this->logError();
            return false;
        }
    }

    // جلب صف واحد
    public function fetch() {
        return $this->stmt->fetch();
    }

    // جلب جميع الصفوف
    public function fetchAll() {
        return $this->stmt->fetchAll();
    }

    // جلب عمود واحد
    public function fetchColumn() {
        return $this->stmt->fetchColumn();
    }

    // الحصول على عدد الصفوف المتأثرة
    public function rowCount() {
        return $this->stmt->rowCount();
    }

    // الحصول على آخر معرف تم إدخاله
    public function lastInsertId() {
        return $this->pdo->lastInsertId();
    }

    // بدء المعاملة
    public function beginTransaction() {
        if ($this->transaction_count == 0) {
            $this->pdo->beginTransaction();
        }
        $this->transaction_count++;
        return $this;
    }

    // تأكيد المعاملة
    public function commit() {
        $this->transaction_count--;
        if ($this->transaction_count == 0) {
            return $this->pdo->commit();
        }
        return true;
    }

    // التراجع عن المعاملة
    public function rollback() {
        if ($this->transaction_count > 0) {
            $this->transaction_count = 0;
            return $this->pdo->rollBack();
        }
        return false;
    }

    // إدخال بيانات
    public function insert($table, $data) {
        $fields = array_keys($data);
        $values = array_fill(0, count($fields), '?');
        
        $sql = "INSERT INTO {$table} (" . implode(', ', $fields) . ") 
                VALUES (" . implode(', ', $values) . ")";
        
        return $this->prepare($sql)->execute(array_values($data));
    }

    // تحديث بيانات
    public function update($table, $data, $where, $where_params = []) {
        $fields = array_map(function($field) {
            return "{$field} = ?";
        }, array_keys($data));
        
        $sql = "UPDATE {$table} SET " . implode(', ', $fields) . " WHERE {$where}";
        
        return $this->prepare($sql)->execute(array_merge(array_values($data), $where_params));
    }

    // حذف بيانات
    public function delete($table, $where, $params = []) {
        $sql = "DELETE FROM {$table} WHERE {$where}";
        return $this->prepare($sql)->execute($params);
    }

    // تنفيذ استعلام مخصص
    public function query($sql, $params = []) {
        $this->prepare($sql);
        return $this->execute($params);
    }

    // الحصول على معلومات الجدول
    public function getTableInfo($table) {
        $sql = "SHOW COLUMNS FROM {$table}";
        $this->prepare($sql)->execute();
        return $this->fetchAll();
    }

    // إنشاء نسخة احتياطية
    public function backup($tables = '*') {
        try {
            $output = '';
            
            if ($tables == '*') {
                $tables = [];
                $this->prepare('SHOW TABLES')->execute();
                while ($row = $this->fetch()) {
                    $tables[] = reset($row);
                }
            } else {
                $tables = is_array($tables) ? $tables : explode(',', $tables);
            }
            
            foreach ($tables as $table) {
                // هيكل الجدول
                $this->prepare("SHOW CREATE TABLE {$table}")->execute();
                $row = $this->fetch();
                $output .= "\n\n" . $row['Create Table'] . ";\n\n";
                
                // بيانات الجدول
                $this->prepare("SELECT * FROM {$table}")->execute();
                while ($row = $this->fetch()) {
                    $fields = array_map(function($value) {
                        return $this->pdo->quote($value);
                    }, $row);
                    $output .= "INSERT INTO {$table} VALUES (" . implode(', ', $fields) . ");\n";
                }
            }
            
            $backup_file = BACKUP_PATH . '/backup_' . date('Y-m-d_H-i-s') . '.sql';
            file_put_contents($backup_file, $output);
            return $backup_file;
            
        } catch (PDOException $e) {
            $this->error = $e->getMessage();
            $this->logError();
            return false;
        }
    }

    // استعادة نسخة احتياطية
    public function restore($backup_file) {
        try {
            $sql = file_get_contents($backup_file);
            $this->pdo->exec($sql);
            return true;
        } catch (PDOException $e) {
            $this->error = $e->getMessage();
            $this->logError();
            return false;
        }
    }

    // تنظيف الجداول
    public function optimize($tables = '*') {
        if ($tables == '*') {
            $tables = [];
            $this->prepare('SHOW TABLES')->execute();
            while ($row = $this->fetch()) {
                $tables[] = reset($row);
            }
        } else {
            $tables = is_array($tables) ? $tables : explode(',', $tables);
        }
        
        foreach ($tables as $table) {
            $this->query("OPTIMIZE TABLE {$table}");
        }
        
        return true;
    }

    // تسجيل الأخطاء
    private function logError() {
        $error_message = date('Y-m-d H:i:s') . " Database Error: " . $this->error . "\n";
        error_log($error_message, 3, ROOT_PATH . '/logs/database.log');
    }

    // الحصول على آخر خطأ
    public function getError() {
        return $this->error;
    }
}

// دوال مساعدة للتعامل مع قاعدة البيانات

function db() {
    return Database::getInstance();
}

function getRow($query, $params = []) {
    $db = db();
    $db->prepare($query);
    $db->execute($params);
    return $db->fetch();
}

function getAll($query, $params = []) {
    $db = db();
    $db->prepare($query);
    $db->execute($params);
    return $db->fetchAll();
}

function getValue($query, $params = []) {
    $db = db();
    $db->prepare($query);
    $db->execute($params);
    return $db->fetchColumn();
}

function execute($query, $params = []) {
    $db = db();
    $db->prepare($query);
    return $db->execute($params);
}

// تصدير كائن قاعدة البيانات
$db = Database::getInstance();