<?php
// منع الوصول المباشر للملف
if (!defined('SECURE_ACCESS')) {
    die('Access Denied');
}

// دوال التحقق من الصلاحيات
function checkPermission($permission) {
    if (!isset($_SESSION['user_permissions']) || 
        !in_array($permission, $_SESSION['user_permissions'])) {
        return false;
    }
    return true;
}

function requirePermission($permission) {
    if (!checkPermission($permission)) {
        redirect('error.php?type=permission');
    }
}

// دوال المصادقة
function generateToken() {
    return bin2hex(random_bytes(32));
}

function verifyToken($token) {
    return isset($_SESSION['csrf_token']) && hash_equals($_SESSION['csrf_token'], $token);
}

// دوال التنقل
function redirect($path) {
    header("Location: " . SITE_URL . "/$path");
    exit();
}

// دوال معالجة الملفات
function uploadFile($file, $destination, $allowed_types = ALLOWED_FILE_TYPES) {
    if ($file['error'] !== UPLOAD_ERR_OK) {
        throw new Exception('خطأ في رفع الملف');
    }

    $file_info = pathinfo($file['name']);
    $extension = strtolower($file_info['extension']);

    if (!in_array($extension, $allowed_types)) {
        throw new Exception('نوع الملف غير مسموح به');
    }

    if ($file['size'] > MAX_FILE_SIZE) {
        throw new Exception('حجم الملف كبير جداً');
    }

    $new_filename = uniqid() . '.' . $extension;
    $upload_path = UPLOADS_PATH . '/' . $destination . '/' . $new_filename;

    if (!move_uploaded_file($file['tmp_name'], $upload_path)) {
        throw new Exception('فشل في رفع الملف');
    }

    return $new_filename;
}

// دوال معالجة النصوص
function sanitizeInput($input) {
    if (is_array($input)) {
        return array_map('sanitizeInput', $input);
    }
    return htmlspecialchars(trim($input), ENT_QUOTES, 'UTF-8');
}

function formatCurrency($amount) {
    return number_format($amount, 2) . ' ' . DEFAULT_CURRENCY;
}

function formatDate($date, $format = 'Y-m-d') {
    return date($format, strtotime($date));
}

// دوال قاعدة البيانات
function getRow($query, $params = []) {
    global $pdo;
    $stmt = $pdo->prepare($query);
    $stmt->execute($params);
    return $stmt->fetch();
}

function getAll($query, $params = []) {
    global $pdo;
    $stmt = $pdo->prepare($query);
    $stmt->execute($params);
    return $stmt->fetchAll();
}

function insert($table, $data) {
    global $pdo;
    $fields = implode(', ', array_keys($data));
    $values = implode(', ', array_fill(0, count($data), '?'));
    
    $query = "INSERT INTO $table ($fields) VALUES ($values)";
    $stmt = $pdo->prepare($query);
    
    return $stmt->execute(array_values($data));
}

function update($table, $data, $where) {
    global $pdo;
    $fields = array_map(function($field) {
        return "$field = ?";
    }, array_keys($data));
    
    $query = "UPDATE $table SET " . implode(', ', $fields) . " WHERE $where";
    $stmt = $pdo->prepare($query);
    
    return $stmt->execute(array_values($data));
}

// دوال النظام
function generateWorkerCode() {
    $prefix = 'W';
    $timestamp = time();
    $random = rand(1000, 9999);
    return $prefix . $timestamp . $random;
}

function calculateProjectProgress($project_id) {
    global $pdo;
    $stmt = $pdo->prepare("
        SELECT 
            (completed_tasks * 100 / total_tasks) as progress
        FROM 
            projects
        WHERE 
            id = ?
    ");
    $stmt->execute([$project_id]);
    return round($stmt->fetchColumn(), 2);
}

function calculateWorkerSalary($worker_id, $start_date, $end_date) {
    global $pdo;
    $stmt = $pdo->prepare("
        SELECT 
            SUM(hours_worked * hourly_rate) as total_salary
        FROM 
            worker_attendance
        WHERE 
            worker_id = ? 
            AND date BETWEEN ? AND ?
    ");
    $stmt->execute([$worker_id, $start_date, $end_date]);
    return $stmt->fetchColumn() ?: 0;
}

// دوال التقارير
function generateReport($type, $params = []) {
    switch ($type) {
        case 'financial':
            return generateFinancialReport($params);
        case 'workers':
            return generateWorkersReport($params);
        case 'projects':
            return generateProjectsReport($params);
        default:
            throw new Exception('نوع التقرير غير معروف');
    }
}

// دوال النسخ الاحتياطي
function createBackup() {
    $backup_file = BACKUP_PATH . '/backup_' . date('Y-m-d_H-i-s') . '.sql';
    $command = sprintf(
        'mysqldump --user=%s --password=%s --host=%s %s > %s',
        DB_USER,
        DB_PASS,
        DB_HOST,
        DB_NAME,
        $backup_file
    );
    
    system($command, $return_var);
    return $return_var === 0;
}

// دوال التحقق
function validateEmail($email) {
    return filter_var($email, FILTER_VALIDATE_EMAIL);
}

function validatePhone($phone) {
    return preg_match('/^(05)[0-9]{8}$/', $phone);
}

function validateNationalId($id) {
    return preg_match('/^[1-2][0-9]{9}$/', $id);
}

// دوال الإشعارات
function addNotification($user_id, $message, $type = 'info') {
    global $pdo;
    return insert('notifications', [
        'user_id' => $user_id,
        'message' => $message,
        'type' => $type,
        'created_at' => date('Y-m-d H:i:s')
    ]);
}

function getUnreadNotifications($user_id) {
    global $pdo;
    return getAll(
        "SELECT * FROM notifications WHERE user_id = ? AND is_read = 0 ORDER BY created_at DESC",
        [$user_id]
    );
}

// دوال التسجيل
function logActivity($user_id, $action, $details = '') {
    global $pdo;
    return insert('activity_log', [
        'user_id' => $user_id,
        'action' => $action,
        'details' => $details,
        'ip_address' => $_SERVER['REMOTE_ADDR'],
        'created_at' => date('Y-m-d H:i:s')
    ]);
}